@@ -1342,6 +1342,9 @@ class RecordParams(AbstractModel):
         :param MaxMediaFileDuration: The maximum file duration allowed (minutes). If the output format is AAC or MP4, and the maximum file duration is exceeded, the file will be segmented. Value range: 1-1440. Default value: 1440 (24 hours). The maximum file size allowed is 2 GB. If the file size exceeds 2 GB, or the file duration exceeds 24 hours, the file will also be segmented.
 This parameter is invalid if the output format is HLS.
         :type MaxMediaFileDuration: int
+        :param MediaId: The type of stream to record. `0`: The primary stream and substream; `1`: The primary stream; `2`: The substream.
+Note: This field may return null, indicating that no valid values can be obtained.
+        :type MediaId: int
         """
         self.RecordMode = None
         self.MaxIdleTime = None
@@ -1350,6 +1353,7 @@ This parameter is invalid if the output format is HLS.
         self.OutputFormat = None
         self.AvMerge = None
         self.MaxMediaFileDuration = None
+        self.MediaId = None
 
 
     def _deserialize(self, params):
@@ -1362,6 +1366,7 @@ This parameter is invalid if the output format is HLS.
         self.OutputFormat = params.get("OutputFormat")
         self.AvMerge = params.get("AvMerge")
         self.MaxMediaFileDuration = params.get("MaxMediaFileDuration")
+        self.MediaId = params.get("MediaId")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
